Automatic Contouring Project — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# Automatic Contouring Project

## Project aim

Accurate contouring is a critical aspect of safe and effective treatment delivery in radiotherapy (RT). Current limitations in clinical practice include large intra and inter-observer variances (IOV), as well as time delays in both contour generation and correction. This study designed and evaluated a 2D U-Net architecture with two primary aims:

1. Automate a time consuming aspect of canine radiotherapy. Specifically, vacuum bag segmentation has been reported to take approximately 30 minutes to contour manually.

2. Evaluate the ability of a 2D U-Net model to achieve expert level performance as defined by Nikolov et al.’s surface dice similarity coefficient 1 with respect to IOV.

The intent for this research is to act as a template for future work extending to other organs.

## Video Demonstrating Usage

Best viewed at 720p+ resolution.

## Details

The Masters thesis developed during this software project has been publicly released to provide a detailed description of the work. It provides details of the model architecture, and examines performance under multiple loss functions. In addition, this work discusses the development of a second model designed to fulfil the need for contouring to become part of regular quality assurance testing.

## References

1

  Nikolov et al. “Deep learning to achieve clinically applicable segmentation of head and neck anatomy for radiotherapy.” (2018): https://arxiv.org/pdf/1809.04430.pdf